gatein SVN: r589 - in portal/trunk: web/eXoResources/src/main/webapp/skin/DefaultSkin/webui/component/UIToolbar and 1 other directory.
by do-not-reply@jboss.org
Author: thanh.do
Date: 2009-11-13 03:31:56 -0500 (Fri, 13 Nov 2009)
New Revision: 589
Modified:
portal/trunk/portlet/exoadmin/src/main/webapp/skin/organization/webui/component/UIOrganizationPortlet/DefaultStylesheet.css
portal/trunk/web/eXoResources/src/main/webapp/skin/DefaultSkin/webui/component/UIToolbar/Stylesheet.css
Log:
GTNPORTAL-238:the actived link should be more clearly visible
Modified: portal/trunk/portlet/exoadmin/src/main/webapp/skin/organization/webui/component/UIOrganizationPortlet/DefaultStylesheet.css
===================================================================
--- portal/trunk/portlet/exoadmin/src/main/webapp/skin/organization/webui/component/UIOrganizationPortlet/DefaultStylesheet.css 2009-11-13 08:29:23 UTC (rev 588)
+++ portal/trunk/portlet/exoadmin/src/main/webapp/skin/organization/webui/component/UIOrganizationPortlet/DefaultStylesheet.css 2009-11-13 08:31:56 UTC (rev 589)
@@ -65,7 +65,7 @@
.UIOrganizationPortlet .UIToolbar .LargeToolbar .SelectButtonLabel {
line-height: 18px;
- color: #058ee6;
+ color: #003C7F;
}
.UIOrganizationPortlet .UIBreadcumbs .LeftBreadcumbsBar {
Modified: portal/trunk/web/eXoResources/src/main/webapp/skin/DefaultSkin/webui/component/UIToolbar/Stylesheet.css
===================================================================
--- portal/trunk/web/eXoResources/src/main/webapp/skin/DefaultSkin/webui/component/UIToolbar/Stylesheet.css 2009-11-13 08:29:23 UTC (rev 588)
+++ portal/trunk/web/eXoResources/src/main/webapp/skin/DefaultSkin/webui/component/UIToolbar/Stylesheet.css 2009-11-13 08:31:56 UTC (rev 589)
@@ -71,18 +71,19 @@
}
.UIToolbar .LargeToolbar a {
- color: black; font-weight: bold;
+ color: #7E9BC9;
+ font-weight: bold;
padding: 0px 3px 0px 3px;
cursor: pointer;
}
.UIToolbar .LargeToolbar a:hover{
- color: #1043b1;
+ color: #003C7F;
}
.UIToolbar .LargeToolbar .SelectButtonLabel {
line-height: 18px;
- color: #058ee6;
+ color: #003C7F;
}
.UIToolbar .LargeToolbar .HorizontalSeparator {
15 years, 1 month
gatein SVN: r588 - portal/trunk/web/portal/src/main/webapp/groovy/webui/form.
by do-not-reply@jboss.org
Author: truong.le
Date: 2009-11-13 03:29:23 -0500 (Fri, 13 Nov 2009)
New Revision: 588
Modified:
portal/trunk/web/portal/src/main/webapp/groovy/webui/form/UIForm.gtmpl
Log:
GTNPORTAL-127: Error in Access permission form of category in Application registry portlet when change language to Russian and Ukrainian
Modified: portal/trunk/web/portal/src/main/webapp/groovy/webui/form/UIForm.gtmpl
===================================================================
--- portal/trunk/web/portal/src/main/webapp/groovy/webui/form/UIForm.gtmpl 2009-11-13 08:07:15 UTC (rev 587)
+++ portal/trunk/web/portal/src/main/webapp/groovy/webui/form/UIForm.gtmpl 2009-11-13 08:29:23 UTC (rev 588)
@@ -11,7 +11,7 @@
<tr>
<%fieldName = uicomponent.getLabel(field.getName());%>
<%
- if(fieldName != null && fieldName.length() > 0 && !fieldName.equals(uicomponent.getId())) {
+ if(fieldName != null && fieldName.length() > 0 && !fieldName.equals(uicomponent.getId()) && !fieldName.equals(field.getName())) {
%>
<td class="FieldLabel">
<%/*if(fieldName != null && fieldName.length() > 0) {*/%>
15 years, 1 month
gatein SVN: r587 - in portal/trunk: webui/portal/src/main/java/org/exoplatform/portal/webui/navigation and 1 other directory.
by do-not-reply@jboss.org
Author: hoang_to
Date: 2009-11-13 03:07:15 -0500 (Fri, 13 Nov 2009)
New Revision: 587
Modified:
portal/trunk/component/portal/src/main/java/org/exoplatform/portal/config/UserPortalConfigService.java
portal/trunk/webui/portal/src/main/java/org/exoplatform/portal/webui/navigation/UIAddGroupNavigation.java
Log:
GTNPORTAL-196: Refactor the code in UIAddGroupNavigation
Modified: portal/trunk/component/portal/src/main/java/org/exoplatform/portal/config/UserPortalConfigService.java
===================================================================
--- portal/trunk/webui/portal/src/main/java/org/exoplatform/portal/webui/navigation/UIAddGroupNavigation.java 2009-11-13 07:48:27 UTC (rev 586)
+++ portal/trunk/webui/portal/src/main/java/org/exoplatform/portal/webui/navigation/UIAddGroupNavigation.java 2009-11-13 08:07:15 UTC (rev 587)
@@ -108,8 +108,8 @@
}
UserPortalConfigService configService = getApplicationComponent(UserPortalConfigService.class);
- Set<String> groupIdsWithNotNavigation = configService.findGroupWithoutNavigation();
- listGroup.removeAll(groupIdsWithNotNavigation);
+ Set<String> groupIdsHavingNavigation = configService.findGroupHavingNavigation();
+ listGroup.removeAll(groupIdsHavingNavigation);
UIVirtualList virtualList = getChild(UIVirtualList.class);
virtualList.dataBind(new ObjectPageList<String>(listGroup, listGroup.size()));
15 years, 1 month
gatein SVN: r586 - portal/trunk/webui/portal/src/main/java/org/exoplatform/portal/webui/portal.
by do-not-reply@jboss.org
Author: tan_pham_dinh
Date: 2009-11-13 02:48:27 -0500 (Fri, 13 Nov 2009)
New Revision: 586
Modified:
portal/trunk/webui/portal/src/main/java/org/exoplatform/portal/webui/portal/UIPortalComponentActionListener.java
Log:
GTNPORTAL-91: Thrown exception when add RSS Reader Gadget in EditInline
Modified: portal/trunk/webui/portal/src/main/java/org/exoplatform/portal/webui/portal/UIPortalComponentActionListener.java
===================================================================
--- portal/trunk/webui/portal/src/main/java/org/exoplatform/portal/webui/portal/UIPortalComponentActionListener.java 2009-11-13 04:59:51 UTC (rev 585)
+++ portal/trunk/webui/portal/src/main/java/org/exoplatform/portal/webui/portal/UIPortalComponentActionListener.java 2009-11-13 07:48:27 UTC (rev 586)
@@ -19,6 +19,7 @@
package org.exoplatform.portal.webui.portal;
+import org.exoplatform.application.gadget.GadgetRegistryService;
import org.exoplatform.application.registry.Application;
import org.exoplatform.commons.utils.PageList;
import org.exoplatform.portal.application.PortalRequestContext;
@@ -28,6 +29,8 @@
import org.exoplatform.portal.config.model.Container;
import org.exoplatform.portal.config.model.TransientApplicationState;
import org.exoplatform.portal.pom.spi.gadget.Gadget;
+import org.exoplatform.portal.pom.spi.portlet.Portlet;
+import org.exoplatform.portal.pom.spi.portlet.Preference;
import org.exoplatform.portal.webui.application.PortletState;
import org.exoplatform.portal.webui.application.UIApplicationList;
import org.exoplatform.portal.webui.application.UIGadget;
@@ -47,6 +50,10 @@
import org.exoplatform.services.organization.OrganizationService;
import org.exoplatform.services.organization.Query;
import org.exoplatform.services.organization.User;
+import org.exoplatform.services.rss.parser.DefaultRSSChannel;
+import org.exoplatform.services.rss.parser.DefaultRSSItem;
+import org.exoplatform.services.rss.parser.RSSDocument;
+import org.exoplatform.services.rss.parser.RSSParser;
import org.exoplatform.web.application.ApplicationMessage;
import org.exoplatform.webui.core.UIComponent;
import org.exoplatform.webui.core.UIContainer;
@@ -55,6 +62,7 @@
import org.exoplatform.webui.event.EventListener;
import org.exoplatform.webui.exception.MessageException;
+import java.net.URI;
import java.util.Date;
import java.util.List;
@@ -243,7 +251,7 @@
UIApplicationList appList = uiApp.findFirstComponentOfType(UIApplicationList.class);
app = appList.getApplication(sourceId);
ApplicationType applicationType = app.getType();
-
+
//TanPD: Hardcoded to fix bug GTNPORTAL-91
Application temp = null;
if (applicationType.equals(ApplicationType.GADGET))
@@ -281,13 +289,35 @@
//
uiPortlet.setState(new PortletState(state, applicationType));
-
+
//TanPD: Fix bug GTNPORTAL-91
if (temp != null && applicationType.equals(ApplicationType.PORTLET))
{
- UIGadget uiGadget = uiPortlet.createUIComponent(UIGadget.class, null, null);
- uiGadget.setState(new TransientApplicationState<Gadget>(temp.getApplicationName()));
- uiPortlet.getPreferences().setValue("url", uiGadget.getUrl());
+ Portlet pref = uiPortlet.getPreferences();
+ try
+ {
+ UIGadget uiGadget = uiPortlet.createUIComponent(UIGadget.class, null, null);
+ uiGadget.setState(new TransientApplicationState<Gadget>(temp.getApplicationName()));
+ pref.setValue("url", uiGadget.getUrl());
+ }
+ catch (Exception e)
+ {
+ //Fix in case: RSS Reader Gadget
+ Preference aggIdPref = pref.getPreference("aggregatorId");
+ String aggregatorId = null;
+ if (aggIdPref == null || aggIdPref.getValue() == null || aggIdPref.getValue().length() == 0)
+ aggregatorId = "rssAggregator";
+ else
+ aggregatorId = aggIdPref.getValue();
+ GadgetRegistryService gadgetSrv = uiApp.getApplicationComponent(GadgetRegistryService.class);
+ org.exoplatform.application.gadget.Gadget gadget = gadgetSrv.getGadget(aggregatorId);
+ //TODO make sure it's an rss feed
+ // TODO make sure that we did not add it already
+ UIGadget uiGadget = uiPortlet.createUIComponent(UIGadget.class, null, null);
+ uiGadget.setState(new TransientApplicationState<org.exoplatform.portal.pom.spi.gadget.Gadget>(
+ gadget.getName()));
+ pref.setValue("url", uiGadget.getUrl());
+ }
}
uiPortlet.setPortletInPortal(uiTarget instanceof UIPortal);
15 years, 1 month
gatein SVN: r585 - portal/trunk/webui/portal/src/main/java/org/exoplatform/portal/webui/page.
by do-not-reply@jboss.org
Author: tan_pham_dinh
Date: 2009-11-12 23:59:51 -0500 (Thu, 12 Nov 2009)
New Revision: 585
Modified:
portal/trunk/webui/portal/src/main/java/org/exoplatform/portal/webui/page/UIPageBrowser.java
Log:
GTNPORTAL-194: Still show popup messages when deleted all page in Page Management
Modified: portal/trunk/webui/portal/src/main/java/org/exoplatform/portal/webui/page/UIPageBrowser.java
===================================================================
--- portal/trunk/webui/portal/src/main/java/org/exoplatform/portal/webui/page/UIPageBrowser.java 2009-11-13 04:50:57 UTC (rev 584)
+++ portal/trunk/webui/portal/src/main/java/org/exoplatform/portal/webui/page/UIPageBrowser.java 2009-11-13 04:59:51 UTC (rev 585)
@@ -268,10 +268,6 @@
LazyPageList datasource = (LazyPageList)repeater.getDataSource();
int currentPage = datasource.getCurrentPage();
service.remove(page);
- uiPageBrowser.defaultValue(uiPageBrowser.getLastQuery());
- if (currentPage > datasource.getAvailablePage())
- currentPage = datasource.getAvailablePage();
- datasource.getPage(currentPage);
UIPortal uiPortal = Util.getUIPortal();
if (uiPortal.getSelectedNode().getPageReference().equals(page.getPageId()))
@@ -283,6 +279,10 @@
}
else
{
+ uiPageBrowser.defaultValue(uiPageBrowser.getLastQuery());
+ if (currentPage > datasource.getAvailablePage())
+ currentPage = datasource.getAvailablePage();
+ datasource.getPage(currentPage);
event.getRequestContext().addUIComponentToUpdateByAjax(uiPageBrowser);
}
}
15 years, 1 month
gatein SVN: r584 - portal/trunk/webui/portal/src/main/java/org/exoplatform/portal/webui/navigation.
by do-not-reply@jboss.org
Author: truong.le
Date: 2009-11-12 23:50:57 -0500 (Thu, 12 Nov 2009)
New Revision: 584
Modified:
portal/trunk/webui/portal/src/main/java/org/exoplatform/portal/webui/navigation/UINavigationNodeSelector.java
Log:
GTNPORTAL-205: Unknown error when edit node's page in special case
Modified: portal/trunk/webui/portal/src/main/java/org/exoplatform/portal/webui/navigation/UINavigationNodeSelector.java
===================================================================
--- portal/trunk/webui/portal/src/main/java/org/exoplatform/portal/webui/navigation/UINavigationNodeSelector.java 2009-11-13 04:04:11 UTC (rev 583)
+++ portal/trunk/webui/portal/src/main/java/org/exoplatform/portal/webui/navigation/UINavigationNodeSelector.java 2009-11-13 04:50:57 UTC (rev 584)
@@ -449,41 +449,54 @@
return;
}
- uiApp.setModeState(UIPortalApplication.APP_BLOCK_EDIT_MODE);
UIWorkingWorkspace uiWorkingWS = uiApp.getChildById(UIPortalApplication.UI_WORKING_WS_ID);
- //uiWorkingWS.setRenderedChild(UIPortalToolPanel.class);
- //uiWorkingWS.addChild(UIPortalComposer.class, "UIPageEditor", null);
-
- uiWorkingWS.setRenderedChild(UIEditInlineWorkspace.class);
-
- UIPortalComposer portalComposer =
- uiWorkingWS.findFirstComponentOfType(UIPortalComposer.class).setRendered(true);
- portalComposer.setShowControl(true);
- portalComposer.setEditted(false);
- portalComposer.setCollapse(false);
- portalComposer.setId("UIPageEditor");
- portalComposer.setComponentConfig(UIPortalComposer.class, "UIPageEditor");
-
UIPortalToolPanel uiToolPanel =
- uiWorkingWS.findFirstComponentOfType(UIPortalToolPanel.class).setRendered(true);
- uiToolPanel.setShowMaskLayer(false);
- uiToolPanel.setWorkingComponent(UIPage.class, null);
- UIPage uiPage = (UIPage)uiToolPanel.getUIComponent();
-
+ uiWorkingWS.findFirstComponentOfType(UIPortalToolPanel.class).setRendered(true);
UserPortalConfigService userService = uiToolPanel.getApplicationComponent(UserPortalConfigService.class);
- WebuiRequestContext context = WebuiRequestContext.getCurrentInstance();
// get selected page
- Page selectPage = null;
- selectPage = userService.getPage(selectedPageNode.getPageReference(), context.getRemoteUser());
- selectPage.setModifier(context.getRemoteUser());
- selectPage.setTitle(selectedPageNode.getLabel());
-
- // convert Page to UIPage
- PortalDataMapper.toUIPage(uiPage, selectPage);
- Util.getPortalRequestContext().addUIComponentToUpdateByAjax(uiWorkingWS);
- Util.getPortalRequestContext().setFullRender(true);
-
+ String pageId = selectedPageNode.getPageReference();
+ Page selectPage = (pageId != null) ? userService.getPage(pageId) : null;
+ if (selectPage != null)
+ {
+ UserACL userACL = uiApp.getApplicationComponent(UserACL.class);
+ if (!userACL.hasPermission(selectPage))
+ {
+ uiApp.addMessage(new ApplicationMessage("UIPageBrowser.msg.UserNotPermission", new String[]{pageId}, 1));
+ return;
+ }
+
+ uiApp.setModeState(UIPortalApplication.APP_BLOCK_EDIT_MODE);
+ //uiWorkingWS.setRenderedChild(UIPortalToolPanel.class);
+ //uiWorkingWS.addChild(UIPortalComposer.class, "UIPageEditor", null);
+
+ uiWorkingWS.setRenderedChild(UIEditInlineWorkspace.class);
+
+ UIPortalComposer portalComposer =
+ uiWorkingWS.findFirstComponentOfType(UIPortalComposer.class).setRendered(true);
+ portalComposer.setShowControl(true);
+ portalComposer.setEditted(false);
+ portalComposer.setCollapse(false);
+ portalComposer.setId("UIPageEditor");
+ portalComposer.setComponentConfig(UIPortalComposer.class, "UIPageEditor");
+
+ uiToolPanel.setShowMaskLayer(false);
+ uiToolPanel.setWorkingComponent(UIPage.class, null);
+ UIPage uiPage = (UIPage)uiToolPanel.getUIComponent();
+
+ WebuiRequestContext context = WebuiRequestContext.getCurrentInstance();
+ selectPage.setModifier(context.getRemoteUser());
+ selectPage.setTitle(selectedPageNode.getLabel());
+
+ // convert Page to UIPage
+ PortalDataMapper.toUIPage(uiPage, selectPage);
+ Util.getPortalRequestContext().addUIComponentToUpdateByAjax(uiWorkingWS);
+ Util.getPortalRequestContext().setFullRender(true);
+ }
+ else
+ {
+ throw new Exception("Page don't exist!");
+ }
}
}
15 years, 1 month
gatein SVN: r583 - in portal/trunk/webui/portal/src/main/java/org/exoplatform/portal/webui: portal and 1 other directory.
by do-not-reply@jboss.org
Author: tan_pham_dinh
Date: 2009-11-12 23:04:11 -0500 (Thu, 12 Nov 2009)
New Revision: 583
Modified:
portal/trunk/webui/portal/src/main/java/org/exoplatform/portal/webui/page/UIPageBody.java
portal/trunk/webui/portal/src/main/java/org/exoplatform/portal/webui/portal/UIPortalComponentActionListener.java
Log:
GTNPORTAL-195: When change node, UIPortal still keeping obsolete page which has 'Show max window' attribute
Modified: portal/trunk/webui/portal/src/main/java/org/exoplatform/portal/webui/page/UIPageBody.java
===================================================================
--- portal/trunk/webui/portal/src/main/java/org/exoplatform/portal/webui/page/UIPageBody.java 2009-11-13 03:40:52 UTC (rev 582)
+++ portal/trunk/webui/portal/src/main/java/org/exoplatform/portal/webui/page/UIPageBody.java 2009-11-13 04:04:11 UTC (rev 583)
@@ -96,6 +96,7 @@
}
}
+ uiPortal.setMaximizedUIComponent(null);
if (page != null)
{
if (Page.DESKTOP_PAGE.equals(page.getFactoryId()))
@@ -109,8 +110,6 @@
PortalDataMapper.toUIPage(uiPage, page);
if (uiPage.isShowMaxWindow())
uiPortal.setMaximizedUIComponent(uiPage);
- else
- uiPortal.setMaximizedUIComponent(null);
}
setUIComponent(uiPage);
}
Modified: portal/trunk/webui/portal/src/main/java/org/exoplatform/portal/webui/portal/UIPortalComponentActionListener.java
===================================================================
--- portal/trunk/webui/portal/src/main/java/org/exoplatform/portal/webui/portal/UIPortalComponentActionListener.java 2009-11-13 03:40:52 UTC (rev 582)
+++ portal/trunk/webui/portal/src/main/java/org/exoplatform/portal/webui/portal/UIPortalComponentActionListener.java 2009-11-13 04:04:11 UTC (rev 583)
@@ -243,6 +243,8 @@
UIApplicationList appList = uiApp.findFirstComponentOfType(UIApplicationList.class);
app = appList.getApplication(sourceId);
ApplicationType applicationType = app.getType();
+
+ //TanPD: Hardcoded to fix bug GTNPORTAL-91
Application temp = null;
if (applicationType.equals(ApplicationType.GADGET))
{
@@ -279,6 +281,8 @@
//
uiPortlet.setState(new PortletState(state, applicationType));
+
+ //TanPD: Fix bug GTNPORTAL-91
if (temp != null && applicationType.equals(ApplicationType.PORTLET))
{
UIGadget uiGadget = uiPortlet.createUIComponent(UIGadget.class, null, null);
15 years, 1 month
gatein SVN: r582 - portal/trunk/portlet/exoadmin/src/main/java/org/exoplatform/toolbar/webui/component.
by do-not-reply@jboss.org
Author: liem_nguyen
Date: 2009-11-12 22:40:52 -0500 (Thu, 12 Nov 2009)
New Revision: 582
Modified:
portal/trunk/portlet/exoadmin/src/main/java/org/exoplatform/toolbar/webui/component/UIUserToolBarSitePortlet.java
Log:
GTNPORTAL-95 Don't show the menu item ( home) of portal when selecting a group page in the navigation group
Modified: portal/trunk/portlet/exoadmin/src/main/java/org/exoplatform/toolbar/webui/component/UIUserToolBarSitePortlet.java
===================================================================
--- portal/trunk/portlet/exoadmin/src/main/java/org/exoplatform/toolbar/webui/component/UIUserToolBarSitePortlet.java 2009-11-12 23:13:56 UTC (rev 581)
+++ portal/trunk/portlet/exoadmin/src/main/java/org/exoplatform/toolbar/webui/component/UIUserToolBarSitePortlet.java 2009-11-13 03:40:52 UTC (rev 582)
@@ -55,7 +55,7 @@
public String getCurrentPortal()
{
- return Util.getUIPortal().getName();
+ return Util.getPortalRequestContext().getPortalOwner();
}
public String getPortalURI(String portalName)
@@ -65,7 +65,7 @@
public PageNavigation getCurrentPortalNavigation() throws Exception
{
- PageNavigation navi = getPageNavigation(PortalConfig.PORTAL_TYPE + "::" + Util.getUIPortal().getName());
+ PageNavigation navi = getPageNavigation(PortalConfig.PORTAL_TYPE + "::" + getCurrentPortal());
String remoteUser = Util.getPortalRequestContext().getRemoteUser();
return PageNavigationUtils.filter(navi, remoteUser);
}
15 years, 1 month
gatein SVN: r581 - in components/wsrp/trunk/consumer: src/test/java/org/gatein/wsrp/test/protocol/v1 and 1 other directory.
by do-not-reply@jboss.org
Author: chris.laprun(a)jboss.com
Date: 2009-11-12 18:13:56 -0500 (Thu, 12 Nov 2009)
New Revision: 581
Modified:
components/wsrp/trunk/consumer/pom.xml
components/wsrp/trunk/consumer/src/test/java/org/gatein/wsrp/test/protocol/v1/ServiceDescriptionBehavior.java
Log:
- Fixed ServiceDescriptionBehavior.setServiceDescription method.
- Re-activated ProducerInfoTestCase which now passes.
Modified: components/wsrp/trunk/consumer/pom.xml
===================================================================
--- components/wsrp/trunk/consumer/pom.xml 2009-11-12 18:46:35 UTC (rev 580)
+++ components/wsrp/trunk/consumer/pom.xml 2009-11-12 23:13:56 UTC (rev 581)
@@ -111,7 +111,6 @@
<exclude>org/gatein/wsrp/protocol/v1/*</exclude>
<exclude>org/gatein/wsrp/consumer/ConsumerRegistryTestCase*</exclude>
<exclude>org/gatein/wsrp/consumer/EndpointConfigurationInfoTestCase*</exclude>
- <exclude>org/gatein/wsrp/consumer/ProducerInfoTestCase*</exclude>
</excludes>
</configuration>
</plugin>
Modified: components/wsrp/trunk/consumer/src/test/java/org/gatein/wsrp/test/protocol/v1/ServiceDescriptionBehavior.java
===================================================================
--- components/wsrp/trunk/consumer/src/test/java/org/gatein/wsrp/test/protocol/v1/ServiceDescriptionBehavior.java 2009-11-12 18:46:35 UTC (rev 580)
+++ components/wsrp/trunk/consumer/src/test/java/org/gatein/wsrp/test/protocol/v1/ServiceDescriptionBehavior.java 2009-11-12 23:13:56 UTC (rev 581)
@@ -61,6 +61,7 @@
protected List<PortletDescription> offeredPortlets;
private boolean requiresRegistration;
private CookieProtocol cookieProtocol;
+ private ModelDescription registrationProperties;
public ServiceDescriptionBehavior()
{
@@ -79,7 +80,10 @@
public void setServiceDescription(boolean requiresRegistration, int numberOfProps)
{
- serviceDescription = createServiceDescription(requiresRegistration, numberOfProps);
+ ServiceDescription sd = createServiceDescription(requiresRegistration, numberOfProps);
+ offeredPortlets = sd.getOfferedPortlets();
+ this.requiresRegistration = sd.isRequiresRegistration();
+ registrationProperties = sd.getRegistrationPropertyDescription();
}
public static ServiceDescription getDefaultServiceDescription()
@@ -145,5 +149,6 @@
offeredPortlets.value = this.offeredPortlets;
requiresRegistration.value = this.requiresRegistration;
requiresInitCookie.value = this.cookieProtocol;
+ registrationPropertyDescription.value = registrationProperties;
}
}
15 years, 1 month
gatein SVN: r580 - portal/trunk/webui/portal/src/main/java/org/exoplatform/portal/webui/application.
by do-not-reply@jboss.org
Author: mwringe
Date: 2009-11-12 13:46:35 -0500 (Thu, 12 Nov 2009)
New Revision: 580
Modified:
portal/trunk/webui/portal/src/main/java/org/exoplatform/portal/webui/application/UIPortlet.java
portal/trunk/webui/portal/src/main/java/org/exoplatform/portal/webui/application/UIPortletActionListener.java
Log:
Update issues with public render parameters. Should be now be properly set before and after the invocation (GTNPORTAL-206)
Modified: portal/trunk/webui/portal/src/main/java/org/exoplatform/portal/webui/application/UIPortlet.java
===================================================================
--- portal/trunk/webui/portal/src/main/java/org/exoplatform/portal/webui/application/UIPortlet.java 2009-11-12 12:42:15 UTC (rev 579)
+++ portal/trunk/webui/portal/src/main/java/org/exoplatform/portal/webui/application/UIPortlet.java 2009-11-12 18:46:35 UTC (rev 580)
@@ -152,7 +152,6 @@
private List<String> supportedPublicParams_;
private boolean portletInPortal_ = true;
private StateString navigationalState;
- private Map<String, String[]> publicNavigationalStateChanges;
public UIPortlet()
{
@@ -659,8 +658,8 @@
// Navigational state
invocation.setNavigationalState(navigationalState);
- // Public navigational state
- invocation.setPublicNavigationalState(publicNavigationalStateChanges);
+ // Public navigational state
+ invocation.setPublicNavigationalState(this.getPublicParameters());
// Mode
invocation.setMode(Mode.create(getCurrentPortletMode().toString()));
@@ -668,9 +667,6 @@
// Window state
invocation.setWindowState(org.gatein.pc.api.WindowState.create(getCurrentWindowState().toString()));
- // Public navigational state
- invocation.setPublicNavigationalState(this.getPublicParameters());
- //
StatefulPortletContext<C> preferencesPortletContext = getPortletContext();
// get the user profile cached in the prc during the start of the request
@@ -850,9 +846,4 @@
{
this.navigationalState = navigationalState;
}
-
- void setPublicNavigationalStateUpdates(Map<String, String[]> publicNavigationalStateUpdates)
- {
- this.publicNavigationalStateChanges = publicNavigationalStateUpdates;
- }
}
\ No newline at end of file
Modified: portal/trunk/webui/portal/src/main/java/org/exoplatform/portal/webui/application/UIPortletActionListener.java
===================================================================
--- portal/trunk/webui/portal/src/main/java/org/exoplatform/portal/webui/application/UIPortletActionListener.java 2009-11-12 12:42:15 UTC (rev 579)
+++ portal/trunk/webui/portal/src/main/java/org/exoplatform/portal/webui/application/UIPortletActionListener.java 2009-11-12 18:46:35 UTC (rev 580)
@@ -87,6 +87,10 @@
UIPortlet<S, C> uiPortlet = event.getSource();
PortalRequestContext prcontext = (PortalRequestContext)event.getRequestContext();
+ // set the public render parameters from the request before creating the invocation
+ HttpServletRequest request = prcontext.getRequest();
+ setupPublicRenderParams(uiPortlet, request.getParameterMap());
+
//
ActionInvocation actionInvocation = uiPortlet.create(ActionInvocation.class, prcontext);
@@ -152,10 +156,6 @@
PortletMode mode = new PortletMode(getPortletModeOrDefault(navStateResponse));
setNextMode(uiPortlet, mode);
- // set the public params
- HttpServletRequest request = prcontext.getRequest();
- setupPublicRenderParams(uiPortlet, navStateResponse.getPublicNavigationalStateUpdates());
-
/*
* Cache the render parameters in the UI portlet component to handle the
* navigational state. Each time a portlet is rendered (except using
@@ -166,8 +166,10 @@
//
StateString navigationalState = navStateResponse.getNavigationalState();
uiPortlet.setNavigationalState(navigationalState);
- uiPortlet.setPublicNavigationalStateUpdates(navStateResponse.getPublicNavigationalStateUpdates());
+ // update the public render parameters with the changes from the invocation
+ setupPublicRenderParams(uiPortlet, navStateResponse.getPublicNavigationalStateUpdates());
+
/*
* Handle the events returned by the action output and broadcast a new UI
* event to the ProcessEventsActionListener that will then target the
15 years, 1 month
--- portal/trunk/component/portal/src/main/java/org/exoplatform/portal/config/UserPortalConfigService.java 2009-11-13 07:48:27 UTC (rev 586)
+++ portal/trunk/component/portal/src/main/java/org/exoplatform/portal/config/UserPortalConfigService.java 2009-11-13 08:07:15 UTC (rev 587)
@@ -530,13 +530,13 @@
}
/**
* Returns the list of group ids that do not have an existing navigation.
*
* @return the group id with no navigation
* @throws Exception
* any exception
*/
- public Set<String> findGroupWithoutNavigation() throws Exception
+ public Set<String> findGroupHavingNavigation() throws Exception
{
Query<PageNavigation> query = new Query<PageNavigation>(PortalConfig.GROUP_TYPE, null, PageNavigation.class);
Set<String> groupIds = new HashSet<String>();
@@ -530,13 +530,13 @@
}
/**
- * Returns the list of group ids that do not have an existing navigation.
+ * Returns the list of group ids having navigation.
*
@@ -530,13 +530,13 @@
*
- * @return the group id with no navigation
+ * @return the group id having navigation
* @throws Exception
* any exception
Modified: portal/trunk/webui/portal/src/main/java/org/exoplatform/portal/webui/navigation/UIAddGroupNavigation.java
===================================================================